Covasim

##### About Covasim

Covasim is an agent-based model that simulates the transmission of COVID-19 (novel coronavirus, SARS-CoV-2) in a population. Each individual in the model may pass through the following stages of COVID-19 infection: susceptible, exposed, infectious, and recovered (SEIR). The epidemiological parameter values are taken from literature.

Viral transmission occurs on a fixed contact network with undirected edges. Each day, infectious individuals expose susceptible individuals in neighboring nodes to possible infection. By default, the daily probability of infection, number of contacts, and mean duration of infectiousness roughly equates to R0 = 2.05 and a doubling time of 6-7 days. For more information, please visit the GitHub repository.

Note: Models are only as good as the values of the parameters put into them. This is a rapidly changing situation, and we will update content as relevant information is received.

Simulation parameters
{{par.name}}:
{{par.tip}}
Epidemiological parameters
{{par.name}}:
{{par.tip}}
Reset parameters to default values
Example parameter configurations
Download parameters
Upload parameters
History of parameters used in this session

During the simulation, the following warning(s) were encountered:

{{ err }}

Results